@@ -1,8 +1,7 @@
-from .rest import RestClient
+from ..rest import RestClient
 
 
 class EmailTemplates(object):
-
     """Auth0 email templates endpoints
 
     Args:
@@ -17,16 +16,32 @@ class EmailTemplates(object):
             connect and read timeout. Pass a tuple to specify
             both values separately or a float to set both to it.
             (defaults to 5.0 for both)
+
+        rest_options (RestClientOptions): Pass an instance of
+            RestClientOptions to configure additional RestClient
+            options, such as rate-limit retries.
+            (defaults to None)
     """
 
-    def __init__(self, domain, token, telemetry=True, timeout=5.0):
+    def __init__(
+        self,
+        domain,
+        token,
+        telemetry=True,
+        timeout=5.0,
+        protocol="https",
+        rest_options=None,
+    ):
         self.domain = domain
-        self.client = RestClient(jwt=token, telemetry=telemetry, timeout=timeout)
+        self.protocol = protocol
+        self.client = RestClient(
+            jwt=token, telemetry=telemetry, timeout=timeout, options=rest_options
+        )
 
     def _url(self, id=None):
-        url = 'https://{}/api/v2/email-templates'.format(self.domain)
+        url = "{}://{}/api/v2/email-templates".format(self.protocol, self.domain)
         if id is not None:
-            return '{}/{}'.format(url, id)
+            return "{}/{}".format(url, id)
         return url
 
     def create(self, body):
@@ -34,7 +49,8 @@ class EmailTemplates(object):
 
         Args:
            body (dict): Attributes for the new email template.
-              See: https://auth0.com/docs/api/management/v2#!/Email_Templates/post_email_templates
+
+        See: https://auth0.com/docs/api/management/v2#!/Email_Templates/post_email_templates
         """
 
         return self.client.post(self._url(), data=body)
@@ -63,8 +79,8 @@ class EmailTemplates(object):
               'change_password', 'password_reset', 'mfa_oob_code'.
 
            body (dict): Attributes to update on the email template.
-              See: https://auth0.com/docs/api/management/v2#!/Email_Templates/patch_email_templates_by_templateName
 
+        See: https://auth0.com/docs/api/management/v2#!/Email_Templates/patch_email_templates_by_templateName
         """
 
         return self.client.patch(self._url(template_name), data=body)
